% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RD_empirical_analysis.R
\name{FullAnalysis}
\alias{FullAnalysis}
\title{Replicate full analysis, using saved results if available}
\usage{
FullAnalysis(d, Cs, save.prefix, fig.prefix = NULL, se.initial = "IKEHW",
  ylab = "", C.ticks = NULL, kern = "triangular", se.method,
  quiet = TRUE)
}
\arguments{
\item{d}{object of class \code{"RDData"}}

\item{Cs}{vector of smoothness parameters}

\item{save.prefix}{Prefix for saving results of analysis as .RData file}

\item{fig.prefix}{Prefix for saving figures as .tex file}

\item{se.initial}{Method for estimating initial variance for computing
    optimal bandwidth. Ignored if data already contains estimate of variance.

\describe{

\item{"IKEHW"}{Based on residuals from a local linear regression using a
              triangular kernel and IK bandwidth}

\item{"IKdemeaned"}{Based on sum of squared deviations of outcome from
              estimate of intercept in local linear regression with
              triangular kernel and IK bandwidth}

\item{"Silverman"}{Use residuals from local constant regression with uniform
kernel and bandwidth selected using Silverman's rule of thumb, as in Equation
(14) in IK}
\item{"SilvermanNN"}{Use nearest neighbor estimates, rather than residuals}

\item{"NN"}{Use nearest neighbor estimates, without assuming homoscedasticity}
}}

\item{ylab}{y-label for y-axis in plots}

\item{C.ticks}{indices to C to display on x-axis of graphs}

\item{kern}{specifies kernel function used in the local regression. It can
either be a string equal to \code{"triangular"} (\eqn{k(u)=(1-|u|)_{+}}),
\code{"epanechnikov"} (\eqn{k(u)=(3/4)(1-u^2)_{+}}), or \code{"uniform"}
(\eqn{k(u)= (|u|<1)/2}), or else a kernel function.}

\item{se.method}{Vector with methods for estimating standard error of
estimate. If \code{NULL}, standard errors are not computed. The elements of
the vector can consist of the following methods:

\describe{
    \item{"nn"}{Nearest neighbor method}

    \item{"EHW"}{Eicker-Huber-White, with residuals from local regression
    (local polynomial estimators only).}

    \item{"demeaned"}{Use EHW, but instead of using residuals, estimate
        \eqn{sigma^2_i} by subtracting the estimated intercept from the
        outcome (and not subtracting the estimated slope). Local
        polynomial estimators only.}

   \item{"plugin"}{Plug-in estimate based on asymptotic variance. Local
        polynomial estimators in RD only.}

   \item{"supplied.var"}{Use conditional variance supplied by \code{sigma2} /
        \code{d} instead of computing residuals}

}}

\item{quiet}{print Empirical Analysis results?}
}
\description{
Replicate full analysis, using saved results if available
}
