% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RD_empirical_analysis.R
\name{HolderAnalysis}
\alias{HolderAnalysis}
\title{Replicate empirical analysis in Honest paper}
\usage{
HolderAnalysis(d, kern, Ms = NULL, bws = NULL, se.method = "nn", J = 3,
  alpha = 0.05)
}
\arguments{
\item{d}{object of class \code{"RDData"}}

\item{kern}{specifies kernel function used in the local regression. It can
either be a string equal to \code{"triangular"} (\eqn{k(u)=(1-|u|)_{+}}),
\code{"epanechnikov"} (\eqn{k(u)=(3/4)(1-u^2)_{+}}), or \code{"uniform"}
(\eqn{k(u)= (|u|<1)/2}), or else a kernel function.}

\item{Ms}{vector of smoothness parameters M, such that the second derivative
is bounded by M (i.e. \eqn{M=2C} in finite-sample paper)}

\item{bws}{bandwidths}

\item{se.method}{Vector with methods for estimating standard error of
estimate. If \code{NULL}, standard errors are not computed. The elements of
the vector can consist of the following methods:

\describe{
    \item{"nn"}{Nearest neighbor method}

    \item{"EHW"}{Eicker-Huber-White, with residuals from local regression
    (local polynomial estimators only).}

    \item{"demeaned"}{Use EHW, but instead of using residuals, estimate
        \eqn{sigma^2_i} by subtracting the estimated intercept from the
        outcome (and not subtracting the estimated slope). Local
        polynomial estimators only.}

   \item{"plugin"}{Plug-in estimate based on asymptotic variance. Local
        polynomial estimators in RD only.}

   \item{"supplied.var"}{Use conditional variance supplied by \code{sigma2} /
        \code{d} instead of computing residuals}

}}

\item{J}{Number of nearest neighbors, if "nn" is specified in
\code{se.method}.}

\item{alpha}{determines confidence level, \code{1-alpha} for
constructing/optimizing confidence intervals.}
}
\description{
Replicate empirical analysis in Honest paper
}
