% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/kernelEfficiency.R
\name{KerEfficiency}
\alias{KerEfficiency}
\title{Relative efficiency of kernels under Holder or Taylor smoothness class}
\usage{
KerEfficiency(kernel = "uniform", order, boundary = TRUE,
  equivalent = FALSE, sclass = "H")
}
\arguments{
\item{kernel}{kernel type. Can be a function supported on \eqn{[-1, 1]}
(boundary kernel) or \eqn{[0,1]} (interior kernel), or else one of "uniform"
(\eqn{I(|u|<1)}), "triangular" (\eqn{(1-|u|)I(|u|<1)}), or "epanechnikov"
(k(u)=(3/4)(1-u^2)I(|u|<1)).}

\item{order}{Order of local polynomial: \code{0} means local constant,
\code{1} local linear, \code{2} local quadratic etc.}

\item{boundary}{Logical scalar, specifying whether we are at a boundary.}

\item{equivalent}{Is the kernel function supplied an equivalent kernel?}

\item{sclass}{Determines smoothness class, one of \code{"T"} (for Taylor) or
\code{"H"} (for Holder)}
}
\value{
list with elements
\describe{
  \item{R}{\eqn{\int k^2}}
  \item{B}{vector of bias constants \eqn{\mathcal{B}_p}, for each order
           \eqn{p}, with some possibly \code{NA} if order is too low }
  \item{Eff}{Kernel efficiency for each order \eqn{p} of the class}
  \item{bw}{bandwidth constant \code{R/B[order+1]^2}}
}
}
\description{
Compute relative efficiency of using a given kernel \code{kernel} and local
polynomial regression of order \code{order} relative to using the optimal
kernel under Holder or Taylor smoothness class of order \code{p}, with
\code{p} equal to 1, 2, or 3.
}
