% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/optimalSYKernels.R
\name{SYKernel}
\alias{SYKernel}
\title{Optimal equivalent kernel in Sacks-Ylvisacker smoothness class.}
\usage{
SYKernel(p, boundary = FALSE, integral = 1/2 + 1/2 * boundary,
  recompute = FALSE, start = NULL)
}
\arguments{
\item{p}{Order of Sacks-Ylvisacker class, positive integer.}

\item{boundary}{Logical scalar, specifying whether we are at a boundary.}

\item{integral}{Positive number that the integral \eqn{\int_0^1 k} should
integrate to. For boundary regression, the default is \code{1}, for
interior regression the default is \code{1/2}.}

\item{recompute}{Should the kernel parameters \eqn{d}, \eqn{C}, and \eqn{b}
be recomputed? Default is \code{FALSE}, in which case pre-computed values
are used if \code{p} is smaller than 5.}

\item{start}{Starding value for computation of \code{d}, only needed if
\code{recompute} is \code{TRUE}.}
}
\value{
a list with names \code{c("k", "b", "d", "C")}, the first element is
    a function that corresponds to the optimal kernel, the remaining three
    elements are the kernel parameters.
}
\description{
Compute the optimal equivalent kernel for Sacks-Ylvisacker smoothness class,
\deqn{\{|f(x)-\sum_{j=0}^{p-1}f^(j)(0)x^j| <= C|x|^p/p!\}.} Parameter of
interest is value of \eqn{f} at a point.
}
\details{
The kernel is normalized to be supported on [-1, 1] (for interior
regression), or [0, 1] (for boundary regression).
}
\examples{
SYKernel(2)
}
