context("Test CCF bias expression")

test_that("Bias correction formula in notes correct", {
    set.seed(42)
    d <- LPDGP(sigma=1, n=1000, M=2, b=c(1/2, 1, 1))
    p <- 1                              # order
    h <- 1/2                            # main bw
    b <- 1/3                            # pilot bw
    beta <- function(p, h) {
        Kh <- pmax(1-abs(d$x/h), 0)         # triangular kernel
        R <- sapply(seq_len(p+1)-1, function(p) d$x^p)
        solve(crossprod(R, Kh*R), crossprod(R, Kh*d$y))
    }

    bias <- (beta(p, h)[1]-beta(p+1, h)[1]) *
        beta(p+1, b)[p+2]/beta(p+1, h)[p+2]

    npr <- nprobust::lprobust(y=d$y, x=d$x, h=h, b=1/3,
                              eval=0, kernel="tri")$Estimate
    ## usual
    expect_equal(npr[5], beta(p, h)[1])
    ## bias-corrected
    expect_equal(npr[6], beta(p, h)[1]-bias)
})
