context("Test empirical analysis")

test_that("Efficiency results from Lee empirical analysis (1511.06028v2)", {

    d <- RDHonest::RDData(RDHonest::lee08, cutoff=0)
    d <- RDHonest::RDPrelimVar(d, "IKdemeaned")
    Cs <- c(0.000180, 0.068900)
    dopt <- tbl_RDTOpt(d, Cs, "supplied.var")

    ## 1. Bounds on adaptation
    expect_equal(dopt$eflci[[1]], c(0.95471961262, 0.95658780015))
    expect_equal(dopt$eoci8[[1]], c(0.97005462206, 0.96136330745))

    ## 2. Comparing OCI, MSE, FLCI
    expect_equal(dopt$oci$delta, rep(2.48647486052, 2))
    expect_equal(dopt$flci$delta, c(4.41698630900, 4.12394945559))
    expect_equal(dopt$oci$hm/dopt$flci$hm, c(0.78669096843, 0.82300486246))
    expect_equal(dopt$e$hm/dopt$flci$hm, c(0.97821368832, 0.97275731576))

    ## 3. Efficiency at MSE
    r1 <- dopt$oci$omega /
        (dopt$e$sd*(qnorm(0.8)+qnorm(0.95)-dopt$e$delta)+dopt$e$omega)
    expect_equal(r1, c(0.97325772084, 0.98143177939))
    expect_equal(dopt$flci$hl/dopt$e$hl, c(0.99952609105, 0.99920035411))

    ## 4. Efficiency of LL
    dll <- tbl_RDLP(d, Cs, kern="triangular", se.method="supplied.var")
    r1 <- (2*dopt$oci$maxbias+dopt$oci$sd*(qnorm(0.95)+qnorm(0.8))) /
        (2*dll$oci$maxbias+dll$oci$sd*(qnorm(0.95)+qnorm(0.8)))
    expect_equal(r1, c(0.97850097796, 0.97104000892))
    expect_equal(dopt$flci$hl/dll$flci$hl, c(0.97845284369, 0.96959629099))

    ## 5. Compute C_naive
    invisible(r1 <- RDAltCI(d, "triangular", 1, RDHonest::IKBW.fit(d),
                            sclass="T", se.method="supplied.var"))
    expect_equal(r1, 0.00212827770)
})
