## This script replicates the simulations in Appendix C.2 in the supplement.

nsimf <- 11000                          # number of simulation draws

library("NPRHonest")
sigmas <- 0.1295*c(1, 4)
## Design parameters
b1 <- c(0.45, 0.25, 0.4)
b2 <- c(0.75, 0.65, 0.9)

des <- data.frame(b1=b1, b2=b2, n=500, unif=TRUE)
nr <- nrow(des)
des <- cbind(data.frame(design=4, M=rep(c(2, 2, 6, 6), each=nr),
                        sigma=0.1295*rep(c(1, 4, 1, 4), each=nr)), des)
## Also add performance at flat f
des <- rbind(des, expand.grid(design=2, M=c(2, 6), sigma=0.1295*c(1, 4),
                              n=500, b1=0, b2=0, unif=TRUE))

filename <- paste0("results/SimResults-", nsimf, ".RData")
if (!file.exists(filename)) {
    r2 <- RDSimulate(p=des[des$M==2, ], Mh=c(2, 6),
                     what="FLCI", nsim=nsimf, eff.row=5)
    r6 <- RDSimulate(p=des[des$M==6, ], Mh=c(2, 6),
                     what="FLCI", nsim=nsimf, eff.row=6)
    simr <- rbind(r2, r6)
    save(simr, file=filename)
} else {
    load(filename)
}

## Make tables
s.nn <- simr[, c(1:5, 8:9, 18, 10, 20)]
s.nn$r.nn <- 100*(1-s.nn$r.nn)
s.ew <- simr[, c(1:5, 8:9, 17, 10, 19)]
s.ew$r.ew <- 100*(1-s.ew$r.ew)

tbl <- function(s, M) {
    t <- cbind(s[s$M==M & s$sigma==0.1295, c(4:10) ],
               s[s$M==M & s$sigma!=0.1295, c(8:10) ])
    cat("\nM=", M, "\n", sep="")
    rownames(t) <- NULL
    print(knitr::kable(t, digits=c(3, 3, 0, 0, 1, 3, 2, 1, 3, 2),
                 row.names=FALSE))
}

tbl(s.nn, 2)
tbl(s.nn, 6)
